/****************************************************************** 
**  ESP32 cumple con dos tareas: 
**  1- Leer datos desde un sensor DHT22.
**  2- Controlar el encendido y apagado de LED en GPIO_5
**  Target       : ESP32 (Tensilica Xtensa LX6 Dual Core 240 Mhz)
**  ToolChain    : Arduino 1.8.13
**  www.firtec.com.ar
*******************************************************************/

#include <WiFi.h>
#include <PubSubClient.h>
#include "HDC1000.h"
HDC1000 hdc1000;

static char Temperatura[7];
static char Humedad[7];
static char cadena[14];
static char cadena_old[14];

const char* ssid = "TP-LINK_50A1AF";
const char* password = "lab_45kl";

// IP del servidor MQTT en Raspberry
const char* mqtt_server = "192.168.1.11";

float t = 0.0, h = 0.00;
boolean bandera = false;

// Crea una instancia del cliente PubSubClient
WiFiClient espClient;
PubSubClient client(espClient);

// GPIO_5 pin del LED
const char led = 5;

// Se definen los topicos o temas
#define TEMP_TOPIC   "firtec/dato1/temp"
#define HUM_TOPIC    "firtec/dato1/hum"
#define LED_TOPIC    "firtec/dato1/led" // 1 SI 0 NO

long lastMsg = 0;
char msg[20];

// Decodifica el mensaje publicado desde el movil
void receivedCallback(char* topic, byte* payload, unsigned int length) {
  Serial.print("Recibido: ");
  Serial.println(topic);

  Serial.print("payload: ");
  for (int i = 0; i < length; i++) {
    Serial.print((char)payload[i]);
  }
  Serial.println();
  /* we got '1' -> on */
  if ((char)payload[0] == '1') {
    digitalWrite(led, HIGH);  // Si es 1 encender el LED
  } else {
    /* we got '0' -> on */
    digitalWrite(led, LOW);  // Si es 0 apagar el LED
  }

}

void mqttconnect() {
  // Bucle de conexión
  while (!client.connected()) {
    Serial.print("MQTT conectando ...");
    // ID del cliente
    String clientId = "ESP32Client";
   
    if (client.connect(clientId.c_str())) {
      Serial.println("conectado!!");
      // Subscribir al tipico con QoS 0
      client.subscribe(LED_TOPIC);
    } else {
      Serial.print("Error, status code =");
      Serial.print(client.state());
      Serial.println("Intentar de nuevo en 5 segundos");
      delay(5000);
    }
  }
}

void setup() {
  Serial.begin(115200);
  Serial.println();
  Serial.print("Conectando con ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print("*");
  }
  // Configura el pin del LED como salida
  pinMode(led, OUTPUT);

  Serial.println("");
  Serial.println("WiFi conectado");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());

  // Configura le IP del servidor y el puerto MQTT
  client.setServer(mqtt_server, 1883);
  /* Funcion receivedCallback que sera invocada cuando 
     el cliente reciba info de un subscripto */
  client.setCallback(receivedCallback);
  hdc1000.begin();
  //dht.begin();
}
void loop() {
  // Si un cliente se desconecta esperar hasta que reconecte
  if (!client.connected()) {
    mqttconnect();
  }
  
  client.loop();
  /* Medir cada tres segundos, NO usar delay() puesto que esta es
     una funcion bloqueante */
  long now = millis();
  if (now - lastMsg > 3000) {
    if(bandera == false) {
    lastMsg = now;
    t = hdc1000.getTemperature();     
         if (t == HDC1000_ERROR_CODE) {
                hdc1000.begin(); // retry once
                t = hdc1000.getTemperature();
          }
     snprintf (msg, 20, "%2.1f", t);   
     client.publish(TEMP_TOPIC, msg); 
     bandera = true; 
    }
    else {
      lastMsg = now;
      h = hdc1000.getHumidity();

          if (h== HDC1000_ERROR_CODE) {
           do{    
                hdc1000.begin(); 
                 h = hdc1000.getHumidity();
           }while(h > 100);       
          }
      snprintf (msg, 20, "%3.1f%%", h);    
      client.publish(HUM_TOPIC, msg);
      bandera = false;
      }
     } 
    }
    
 
