#!/usr/bin/env python
# -*- coding: utf-8 -*-

from luma.core.interface.serial import i2c
from luma.core.render import canvas
from luma.oled.device import ssd1306, ssd1325, ssd1331, sh1106
from time import sleep

import os
import sys
import time
import psutil
from pathlib import Path
from datetime import datetime


if os.name != 'posix':
    sys.exit('{} platform not supported'.format(os.name))

from demo_opts import get_device
from luma.core.render import canvas
from PIL import ImageFont


serial = i2c(port=1, address=0x3C)
device = sh1106(serial, rotate=0)

font_path = str(Path(__file__).resolve().parent.joinpath('fonts', 'C&C Red Alert [INET].ttf'))
font2 = ImageFont.truetype(font_path, 12)

#---------------------------------------------------------
def bytes2human(n):
   
    symbols = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
    prefix = {}
    for i, s in enumerate(symbols):
        prefix[s] = 1 << (i + 1) * 10
    for s in reversed(symbols):
        if n >= prefix[s]:
            value = int(float(n) / prefix[s])
            return '%s%s' % (value, s)
    return "%sB" % n

def cpu_usage():
    # load average, uptime
    uptime = datetime.now() - datetime.fromtimestamp(psutil.boot_time())
    av1, av2, av3 = os.getloadavg()
    return "Ld:%.1f %.1f %.1f Up: %s" \
        % (av1, av2, av3, str(uptime).split('.')[0])
def mem_usage():
    usage = psutil.virtual_memory()
    return "Memoria: %s %.0f%%" \
        % (bytes2human(usage.used), 100 - usage.percent)

def network(iface):
    stat = psutil.net_io_counters(pernic=True)[iface]
    return "%s: Tx%s, Rx%s" % \
           (iface, bytes2human(stat.bytes_sent), bytes2human(stat.bytes_recv))

def disk_usage(dir):
    usage = psutil.disk_usage(dir)
    return "SD:  %s %.0f%%" \
        % (bytes2human(usage.used), usage.percent)
#---------------------------------------------------------
with canvas(device) as draw:
        draw.text((5, 0), "Raspberry PI Status", fill="white")
        draw.text((5, 6), "-------------------", fill="white")
        draw.text((0, 16), mem_usage(), font=font2, fill="white")
        draw.text((0, 30), disk_usage('/'), font=font2, fill="white")
        draw.text((9, 50), "www.firtec.com.ar", fill="white")

sleep(10)

